==> jc-1.4.0.tar.gz: ppg/atoms/TerminalList.h <==
// public class ppg.atoms.TerminalList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 195bb61582abda5d ppg_atoms_TerminalList

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_atoms_TerminalList_H_
#define _JC_ppg_atoms_TerminalList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_ppg_atoms_TerminalList$sub_refs	_jc_ppg_atoms_TerminalList$sub_refs;
typedef struct _jc_ppg_atoms_TerminalList$sub_nonrefs	_jc_ppg_atoms_TerminalList$sub_nonrefs;
typedef struct _jc_ppg_atoms_TerminalList$refs	_jc_ppg_atoms_TerminalList$refs;
typedef struct _jc_ppg_atoms_TerminalList$nonrefs	_jc_ppg_atoms_TerminalList$nonrefs;
typedef struct _jc_ppg_atoms_TerminalList$object	_jc_ppg_atoms_TerminalList$object;

typedef const struct _jc_ppg_atoms_TerminalList$vmethods	_jc_ppg_atoms_TerminalList$vmethods;
typedef const struct _jc_ppg_atoms_TerminalList$vtable	_jc_ppg_atoms_TerminalList$vtable;
typedef const struct _jc_ppg_atoms_TerminalList$vtype	_jc_ppg_atoms_TerminalList$vtype;

// Constructors
extern void _jc_ppg_atoms_TerminalList$method$_init$e2f4d4d6d819f45a(_jc_env *, struct _jc_ppg_atoms_TerminalList$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Vector$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_TerminalList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_TerminalList$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_TerminalList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_atoms_TerminalList$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_TerminalList$object *);
};

// Vtable
struct _jc_ppg_atoms_TerminalList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_TerminalList$vmethods	ppg_atoms_TerminalList;
};

// Vtype
struct _jc_ppg_atoms_TerminalList$vtype {
	_jc_type			type;
	_jc_ppg_atoms_TerminalList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_TerminalList$sub_refs {
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_util_Vector$object	*symbols;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_TerminalList$refs {
    _jc_ppg_atoms_TerminalList$sub_refs	ppg_atoms_TerminalList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_TerminalList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_TerminalList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_TerminalList$sub_nonrefs	ppg_atoms_TerminalList;
};

// Object instance structure
struct _jc_ppg_atoms_TerminalList$object {
	_jc_ppg_atoms_TerminalList$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_TerminalList$vtype	*vtype;
	_jc_ppg_atoms_TerminalList$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_TerminalList$vtype _jc_ppg_atoms_TerminalList$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_TerminalList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_TerminalList$class_object;

#endif	/* _JC_ppg_atoms_TerminalList_H_ */

==> jc-1.4.6.tar.gz: ppg/atoms/TerminalList.h <==
// public class ppg.atoms.TerminalList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195bb61582abda5d ppg_atoms_TerminalList

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_atoms_TerminalList_H_
#define _JC_ppg_atoms_TerminalList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_ppg_atoms_TerminalList$sub_refs	_jc_ppg_atoms_TerminalList$sub_refs;
typedef struct _jc_ppg_atoms_TerminalList$sub_nonrefs	_jc_ppg_atoms_TerminalList$sub_nonrefs;
typedef struct _jc_ppg_atoms_TerminalList$refs	_jc_ppg_atoms_TerminalList$refs;
typedef struct _jc_ppg_atoms_TerminalList$nonrefs	_jc_ppg_atoms_TerminalList$nonrefs;
typedef struct _jc_ppg_atoms_TerminalList$object	_jc_ppg_atoms_TerminalList$object;

typedef const struct _jc_ppg_atoms_TerminalList$vmethods	_jc_ppg_atoms_TerminalList$vmethods;
typedef const struct _jc_ppg_atoms_TerminalList$vtable	_jc_ppg_atoms_TerminalList$vtable;
typedef const struct _jc_ppg_atoms_TerminalList$vtype	_jc_ppg_atoms_TerminalList$vtype;

// Constructors
extern void _jc_ppg_atoms_TerminalList$method$_init$e2f4d4d6d819f45a(_jc_env *, struct _jc_ppg_atoms_TerminalList$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_TerminalList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_TerminalList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_TerminalList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_atoms_TerminalList$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_TerminalList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_atoms_TerminalList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_TerminalList$vmethods	ppg_atoms_TerminalList;
};

// Vtype
struct _jc_ppg_atoms_TerminalList$vtype {
	_jc_type			type;
	_jc_ppg_atoms_TerminalList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_TerminalList$sub_refs {
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_util_Vector$object	*symbols;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_TerminalList$refs {
    _jc_ppg_atoms_TerminalList$sub_refs	ppg_atoms_TerminalList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_TerminalList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_TerminalList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_TerminalList$sub_nonrefs	ppg_atoms_TerminalList;
};

// Object instance structure
struct _jc_ppg_atoms_TerminalList$object {
	_jc_ppg_atoms_TerminalList$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_TerminalList$vtype	*vtype;
	_jc_ppg_atoms_TerminalList$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_TerminalList$vtype _jc_ppg_atoms_TerminalList$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_TerminalList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_TerminalList$class_object;

#endif	/* _JC_ppg_atoms_TerminalList_H_ */
